@@ -7,7 +7,7 @@ import (
 	"strconv"
 	"time"
 
-	"github.com/containers/podman/v3/pkg/annotations"
+	"github.com/containers/podman/v4/pkg/annotations"
 	"github.com/cri-o/cri-o/internal/config/capabilities"
 	"github.com/cri-o/cri-o/internal/hostport"
 	"github.com/cri-o/cri-o/internal/lib"
@@ -253,6 +253,24 @@ var _ = t.Describe("Container", func() {
 			Expect(sut.ReadOnly(true)).To(Equal(true))
 		})
 	})
+	t.Describe("Restore", func() {
+		It("should not be restore by default", func() {
+			// Given
+			// When
+			// Then
+			Expect(sut.Restore()).To(BeFalse())
+		})
+		It("should be restore when specified", func() {
+			// Given
+			Expect(sut.Restore()).To(BeFalse())
+
+			// When
+			sut.SetRestore(true)
+
+			// Then
+			Expect(sut.Restore()).To(BeTrue())
+		})
+	})
 	t.Describe("SelinuxLabel", func() {
 		BeforeEach(func() {
 			config.Linux = &types.LinuxContainerConfig{
@@ -533,7 +551,7 @@ var _ = t.Describe("Container", func() {
 			var caps *types.Capability
 			serverCaps := capabilities.Default()
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).To(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).To(BeNil())
 			verifyCapValues(sut.Spec().Config.Process.Capabilities, len(serverCaps))
 		})
 		It("AddCapabilities should add capability", func() {
@@ -543,7 +561,7 @@ var _ = t.Describe("Container", func() {
 			}
 			serverCaps := []string{}
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).To(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).To(BeNil())
 			verifyCapValues(sut.Spec().Config.Process.Capabilities, len(serverCaps)+1)
 		})
 		It("DropCapabilities should drop capability", func() {
@@ -553,7 +571,7 @@ var _ = t.Describe("Container", func() {
 			}
 			serverCaps := []string{"CHOWN"}
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).To(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).To(BeNil())
 			verifyCapValues(sut.Spec().Config.Process.Capabilities, len(serverCaps)-1)
 		})
 		It("AddCapabilities ALL DropCapabilities one should drop that one", func() {
@@ -563,7 +581,7 @@ var _ = t.Describe("Container", func() {
 			}
 			serverCaps := []string{}
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).To(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).To(BeNil())
 			verifyCapValues(sut.Spec().Config.Process.Capabilities, len(capability.List())-1)
 		})
 		It("AddCapabilities one DropCapabilities ALL should add that one", func() {
@@ -573,7 +591,7 @@ var _ = t.Describe("Container", func() {
 			}
 			serverCaps := []string{}
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).To(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).To(BeNil())
 			verifyCapValues(sut.Spec().Config.Process.Capabilities, 1)
 		})
 		It("AddCapabilities ALL DropCapabilities ALL should drop all", func() {
@@ -583,7 +601,7 @@ var _ = t.Describe("Container", func() {
 			}
 			serverCaps := []string{}
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).To(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).To(BeNil())
 			verifyCapValues(sut.Spec().Config.Process.Capabilities, 0)
 		})
 		It("Invalid values should fail", func() {
@@ -592,7 +610,17 @@ var _ = t.Describe("Container", func() {
 			}
 			serverCaps := []string{}
 
-			Expect(sut.SpecSetupCapabilities(caps, serverCaps)).NotTo(BeNil())
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, false)).NotTo(BeNil())
+		})
+		It("Should add inheritable capabilities if set", func() {
+			caps := &types.Capability{
+				AddCapabilities:  []string{"CHOWN"},
+				DropCapabilities: []string{"ALL"},
+			}
+			serverCaps := []string{}
+
+			Expect(sut.SpecSetupCapabilities(caps, serverCaps, true)).To(BeNil())
+			Expect(len(sut.Spec().Config.Process.Capabilities.Inheritable)).To(Equal(1))
 		})
 	})
 })
