@@ -3,12 +3,11 @@ package runtimehandlerhooks
 import (
 	"encoding/hex"
 	"fmt"
-	"io/ioutil"
 	"os"
-	"os/exec"
 	"strings"
 	"unicode"
 
+	"github.com/cri-o/cri-o/utils/cmdrunner"
 	"github.com/sirupsen/logrus"
 	"k8s.io/kubernetes/pkg/kubelet/cm/cpuset"
 )
@@ -138,11 +137,11 @@ func UpdateIRQSmpAffinityMask(cpus, current string, set bool) (cpuMask, bannedCP
 }
 
 func restartIrqBalanceService() error {
-	return exec.Command("systemctl", "restart", "irqbalance").Run()
+	return cmdrunner.Command("systemctl", "restart", "irqbalance").Run()
 }
 
 func isServiceEnabled(serviceName string) bool {
-	cmd := exec.Command("systemctl", "is-enabled", serviceName)
+	cmd := cmdrunner.Command("systemctl", "is-enabled", serviceName)
 	status, err := cmd.CombinedOutput()
 	if err != nil {
 		logrus.Infof("Service %s is-enabled check returned with: %v", serviceName, err)
@@ -155,7 +154,7 @@ func isServiceEnabled(serviceName string) bool {
 }
 
 func updateIrqBalanceConfigFile(irqBalanceConfigFile, newIRQBalanceSetting string) error {
-	input, err := ioutil.ReadFile(irqBalanceConfigFile)
+	input, err := os.ReadFile(irqBalanceConfigFile)
 	if err != nil {
 		return err
 	}
@@ -163,7 +162,7 @@ func updateIrqBalanceConfigFile(irqBalanceConfigFile, newIRQBalanceSetting strin
 	found := false
 	for i, line := range lines {
 		if strings.HasPrefix(line, irqBalanceBannedCpus+"=") {
-			lines[i] = irqBalanceBannedCpus + "=" + "\"" + newIRQBalanceSetting + "\"" + "\n"
+			lines[i] = irqBalanceBannedCpus + "=" + "\"" + newIRQBalanceSetting + "\""
 			found = true
 		}
 	}
@@ -171,14 +170,14 @@ func updateIrqBalanceConfigFile(irqBalanceConfigFile, newIRQBalanceSetting strin
 	if !found {
 		output = output + "\n" + irqBalanceBannedCpus + "=" + "\"" + newIRQBalanceSetting + "\"" + "\n"
 	}
-	if err := ioutil.WriteFile(irqBalanceConfigFile, []byte(output), 0644); err != nil {
+	if err := os.WriteFile(irqBalanceConfigFile, []byte(output), 0o644); err != nil {
 		return err
 	}
 	return nil
 }
 
 func retrieveIrqBannedCPUMasks(irqBalanceConfigFile string) (string, error) {
-	input, err := ioutil.ReadFile(irqBalanceConfigFile)
+	input, err := os.ReadFile(irqBalanceConfigFile)
 	if err != nil {
 		return "", err
 	}
